All of lore.kernel.org
 help / color / mirror / Atom feed
* [PATCH 1/63] usb/message: make usb_{control,bulk}_msg() use msecs
@ 2005-05-19  6:25 ` Nishanth Aravamudan
  0 siblings, 0 replies; 6+ messages in thread
From: Nishanth Aravamudan @ 2005-02-09  0:12 UTC (permalink / raw)
  To: gregkh, marcel, maxk, jt, perex, linux-dvb-maintainer, johnpol
  Cc: linux-usb-devel, bluez-devel, irda-users, alsa-devel, linux-dvb,
	sensors

Hi,

Sent to everyone so that build and compile tests will be possible. Only Greg
should need to pull this into a tree, though, to send upstream.

Thanks,
Nish

Description: Change the units of the timeout parameter in both usb_control_msg()
and usb_bulk_msg() from jiffies to milliseconds. This is the core patch upon
which the remaining ones will be built. Patch is compile-tested.

Signed-off-by: Nishanth Aravamudan <nacc@us.ibm.com>

--- 2.6.11-rc3-kj-v/drivers/usb/core/message.c	2005-02-03 16:57:40.000000000 -0800
+++ 2.6.11-rc3-kj/drivers/usb/core/message.c	2005-02-08 16:07:32.000000000 -0800
@@ -98,7 +98,7 @@ int usb_internal_control_msg(struct usb_
 	usb_fill_control_urb(urb, usb_dev, pipe, (unsigned char *)cmd, data,
 			     len, usb_api_blocking_completion, NULL);
 
-	retv = usb_start_wait_urb(urb, timeout, &length);
+	retv = usb_start_wait_urb(urb, msecs_to_jiffies(timeout), &length);
 	if (retv < 0)
 		return retv;
 	else
@@ -115,7 +115,7 @@ int usb_internal_control_msg(struct usb_
  *	@index: USB message index value
  *	@data: pointer to the data to send
  *	@size: length in bytes of the data to send
  *	@timeout: time in jiffies to wait for the message to complete before
  *		timing out (if 0 the wait is forever)
  *	Context: !in_interrupt ()
  *
@@ -163,7 +163,7 @@ int usb_control_msg(struct usb_device *d
  *	@data: pointer to the data to send
  *	@len: length in bytes of the data to send
  *	@actual_length: pointer to a location to put the actual length transferred in bytes
  *	@timeout: time in jiffies to wait for the message to complete before
  *		timing out (if 0 the wait is forever)
  *	Context: !in_interrupt ()
  *
@@ -196,7 +196,7 @@ int usb_bulk_msg(struct usb_device *usb_
 	usb_fill_bulk_urb(urb, usb_dev, pipe, data, len,
 			  usb_api_blocking_completion, NULL);
 
-	return usb_start_wait_urb(urb,timeout,actual_length);
+	return usb_start_wait_urb(urb,msecs_to_jiffies(timeout),actual_length);
 }
 
 /*-------------------------------------------------------------------*/

^ permalink raw reply	[flat|nested] 6+ messages in thread

* Re: [linux-usb-devel] [PATCH 1/63] usb/message: make usb_{control,bulk}_msg() use msecs
  2005-05-19  6:25 ` Nishanth Aravamudan
@ 2005-05-19  6:25   ` Greg KH
  -1 siblings, 0 replies; 6+ messages in thread
From: Greg KH @ 2005-02-15 22:29 UTC (permalink / raw)
  To: Nishanth Aravamudan
  Cc: gregkh, marcel, maxk, jt, perex, linux-dvb-maintainer, johnpol,
	linux-usb-devel, bluez-devel, irda-users, alsa-devel, linux-dvb,
	sensors

On Tue, Feb 08, 2005 at 04:12:32PM -0800, Nishanth Aravamudan wrote:
> Hi,
> 
> Sent to everyone so that build and compile tests will be possible. Only Greg
> should need to pull this into a tree, though, to send upstream.

Ugh, 63+ patches...

Anyway, I've applied all of these, and your additional one, to my tree.
If you could make sure and check the next -mm release to make sure I got
them all, I'd appreciate it.

thanks a lot for your work, I appreciate it.

greg k-h


-------------------------------------------------------
SF email is sponsored by - The IT Product Guide
Read honest & candid reviews on hundreds of IT Products from real users.
Discover which products truly live up to the hype. Start reading now.
http://ads.osdn.com/?ad_id=6595&alloc_id=14396&op=click
_______________________________________________
linux-usb-devel@lists.sourceforge.net
To unsubscribe, use the last form field at:
https://lists.sourceforge.net/lists/listinfo/linux-usb-devel

^ permalink raw reply	[flat|nested] 6+ messages in thread

* Re: [linux-usb-devel] [PATCH 1/63] usb/message: make usb_{control,bulk}_msg() use msecs
  2005-05-19  6:25   ` [linux-usb-devel] [PATCH 1/63] usb/message: make Greg KH
@ 2005-05-19  6:25     ` Nishanth Aravamudan
  -1 siblings, 0 replies; 6+ messages in thread
From: Nishanth Aravamudan @ 2005-02-15 23:10 UTC (permalink / raw)
  To: Greg KH
  Cc: gregkh, marcel, maxk, jt, perex, linux-dvb-maintainer, johnpol,
	linux-usb-devel, bluez-devel, irda-users, alsa-devel, linux-dvb,
	sensors

On Tue, Feb 15, 2005 at 02:29:38PM -0800, Greg KH wrote:
> On Tue, Feb 08, 2005 at 04:12:32PM -0800, Nishanth Aravamudan wrote:
> > Hi,
> > 
> > Sent to everyone so that build and compile tests will be possible. Only Greg
> > should need to pull this into a tree, though, to send upstream.
> 
> Ugh, 63+ patches...
> 
> Anyway, I've applied all of these, and your additional one, to my tree.
> If you could make sure and check the next -mm release to make sure I got
> them all, I'd appreciate it.
> 
> thanks a lot for your work, I appreciate it.

No problem! I will keep my eye on the USB tree in the next -MM and make
sure there aren't any stray unchanged usb_{bulk,control}_msg()s around.
Thanks for your help!

-Nish


-------------------------------------------------------
SF email is sponsored by - The IT Product Guide
Read honest & candid reviews on hundreds of IT Products from real users.
Discover which products truly live up to the hype. Start reading now.
http://ads.osdn.com/?ad_id=6595&alloc_id=14396&op=click
_______________________________________________
linux-usb-devel@lists.sourceforge.net
To unsubscribe, use the last form field at:
https://lists.sourceforge.net/lists/listinfo/linux-usb-devel

^ permalink raw reply	[flat|nested] 6+ messages in thread

* [PATCH 1/63] usb/message: make usb_{control,bulk}_msg() use msecs
@ 2005-05-19  6:25 ` Nishanth Aravamudan
  0 siblings, 0 replies; 6+ messages in thread
From: Nishanth Aravamudan @ 2005-05-19  6:25 UTC (permalink / raw)
  To: gregkh, marcel, maxk, jt, perex, linux-dvb-maintainer, johnpol
@@ -115,7 +115,7 @@ int usb_internal_control_msg(struct usb_
  *	@data: pointer to the data to send
  *	@size: length in bytes of the data to send
- *	@timeout: time in jiffies to wait for the message to complete before
+ *	@timeout: time in msecs to wait for the message to complete before
  *		timing out (if 0 the wait is forever)
  *	Context: !in_interrupt ()
@@ -163,7 +163,7 @@ int usb_control_msg(struct usb_device *d
  *	@len: length in bytes of the data to send
  *	@actual_length: pointer to a location to put the actual length transferred in bytes
- *	@timeout: time in jiffies to wait for the message to complete before
+ *	@timeout: time in msecs to wait for the message to complete before
  *		timing out (if 0 the wait is forever)
  *	Context: !in_interrupt ()
  Cc: linux-usb-devel, bluez-devel, irda-users, alsa-devel, linux-dvb,
	sensors

Hi,

Sent to everyone so that build and compile tests will be possible. Only Greg
should need to pull this into a tree, though, to send upstream.

Thanks,
Nish

Description: Change the units of the timeout parameter in both usb_control_msg()
and usb_bulk_msg() from jiffies to milliseconds. This is the core patch upon
which the remaining ones will be built. Patch is compile-tested.

Signed-off-by: Nishanth Aravamudan <nacc@us.ibm.com>

--- 2.6.11-rc3-kj-v/drivers/usb/core/message.c	2005-02-03 16:57:40.000000000 -0800
+++ 2.6.11-rc3-kj/drivers/usb/core/message.c	2005-02-08 16:07:32.000000000 -0800
@@ -98,7 +98,7 @@ int usb_internal_control_msg(struct usb_
 	usb_fill_control_urb(urb, usb_dev, pipe, (unsigned char *)cmd, data,
 			     len, usb_api_blocking_completion, NULL);
 
-	retv = usb_start_wait_urb(urb, timeout, &length);
+	retv = usb_start_wait_urb(urb, msecs_to_jiffies(timeout), &length);
 	if (retv < 0)
 		return retv;
 	else
@@ -115,7 +115,7 @@ int usb_internal_control_msg(struct usb_
  *	@index: USB message index value
  *	@data: pointer to the data to send
  *	@size: length in bytes of the data to send
  *	@timeout: time in jiffies to wait for the message to complete before
  *		timing out (if 0 the wait is forever)
  *	Context: !in_interrupt ()
  *
@@ -163,7 +163,7 @@ int usb_control_msg(struct usb_device *d
  *	@data: pointer to the data to send
  *	@len: length in bytes of the data to send
  *	@actual_length: pointer to a location to put the actual length transferred in bytes
  *	@timeout: time in jiffies to wait for the message to complete before
  *		timing out (if 0 the wait is forever)
  *	Context: !in_interrupt ()
  *
@@ -196,7 +196,7 @@ int usb_bulk_msg(struct usb_device *usb_
 	usb_fill_bulk_urb(urb, usb_dev, pipe, data, len,
 			  usb_api_blocking_completion, NULL);
 
-	return usb_start_wait_urb(urb,timeout,actual_length);
+	return usb_start_wait_urb(urb,msecs_to_jiffies(timeout),actual_length);
 }
 
 /*-------------------------------------------------------------------*/

^ permalink raw reply	[flat|nested] 6+ messages in thread

* [linux-usb-devel] [PATCH 1/63] usb/message: make
@ 2005-05-19  6:25   ` Greg KH
  0 siblings, 0 replies; 6+ messages in thread
From: Greg KH @ 2005-05-19  6:25 UTC (permalink / raw)
  To: Nishanth Aravamudan
  Cc: gregkh, marcel, maxk, jt, perex, linux-dvb-maintainer, johnpol,
	linux-usb-devel, bluez-devel, irda-users, alsa-devel, linux-dvb,
	sensors

On Tue, Feb 08, 2005 at 04:12:32PM -0800, Nishanth Aravamudan wrote:
> Hi,
> 
> Sent to everyone so that build and compile tests will be possible. Only Greg
> should need to pull this into a tree, though, to send upstream.

Ugh, 63+ patches...

Anyway, I've applied all of these, and your additional one, to my tree.
If you could make sure and check the next -mm release to make sure I got
them all, I'd appreciate it.

thanks a lot for your work, I appreciate it.

greg k-h

^ permalink raw reply	[flat|nested] 6+ messages in thread

* [linux-usb-devel] [PATCH 1/63] usb/message: make
@ 2005-05-19  6:25     ` Nishanth Aravamudan
  0 siblings, 0 replies; 6+ messages in thread
From: Nishanth Aravamudan @ 2005-05-19  6:25 UTC (permalink / raw)
  To: Greg KH
  Cc: gregkh, marcel, maxk, jt, perex, linux-dvb-maintainer, johnpol,
	linux-usb-devel, bluez-devel, irda-users, alsa-devel, linux-dvb,
	sensors

On Tue, Feb 15, 2005 at 02:29:38PM -0800, Greg KH wrote:
> On Tue, Feb 08, 2005 at 04:12:32PM -0800, Nishanth Aravamudan wrote:
> > Hi,
> > 
> > Sent to everyone so that build and compile tests will be possible. Only Greg
> > should need to pull this into a tree, though, to send upstream.
> 
> Ugh, 63+ patches...
> 
> Anyway, I've applied all of these, and your additional one, to my tree.
> If you could make sure and check the next -mm release to make sure I got
> them all, I'd appreciate it.
> 
> thanks a lot for your work, I appreciate it.

No problem! I will keep my eye on the USB tree in the next -MM and make
sure there aren't any stray unchanged usb_{bulk,control}_msg()s around.
Thanks for your help!

-Nish

^ permalink raw reply	[flat|nested] 6+ messages in thread

end of thread, other threads:[~2005-05-19  6:25 UTC | newest]

Thread overview: 6+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
@@ -115,7 +115,7 @@ int usb_internal_control_msg(struct usb_
  *	@data: pointer to the data to send
  *	@size: length in bytes of the data to send
- *	@timeout: time in jiffies to wait for the message to complete before
+ *	@timeout: time in msecs to wait for the message to complete before
  *		timing out (if 0 the wait is forever)
  *	Context: !in_interrupt ()
@@ -163,7 +163,7 @@ int usb_control_msg(struct usb_device *d
  *	@len: length in bytes of the data to send
  *	@actual_length: pointer to a location to put the actual length transferred in bytes
- *	@timeout: time in jiffies to wait for the message to complete before
+ *	@timeout: time in msecs to wait for the message to complete before
  *		timing out (if 0 the wait is forever)
  *	Context: !in_interrupt ()
2005-02-09  0:12 [PATCH 1/63] usb/message: make usb_{control,bulk}_msg() use msecs Nishanth Aravamudan
2005-05-19  6:25 ` Nishanth Aravamudan
2005-02-15 22:29 ` [linux-usb-devel] " Greg KH
2005-05-19  6:25   ` [linux-usb-devel] [PATCH 1/63] usb/message: make Greg KH
2005-02-15 23:10   ` [linux-usb-devel] [PATCH 1/63] usb/message: make usb_{control,bulk}_msg() use msecs Nishanth Aravamudan
2005-05-19  6:25     ` [linux-usb-devel] [PATCH 1/63] usb/message: make Nishanth Aravamudan

This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.